# new-containers

Build status:

1. [![](https://github.com/shreyad8/new-containers/workflows/tests-fibonacci/badge.svg)](https://github.com/shreyad8/new-containers/actions?query=workflow%3Atests-fibonacci)
1. [![](https://github.com/shreyad8/new-containers/workflows/tests-range/badge.svg)](https://github.com/shreyad8/new-containers/actions?query=workflow%3Atests-range)
1. ![](https://github.com/shreyad8/new-containers/workflows/tests-BinaryTree/badge.svg)
1. ![](https://github.com/shreyad8/new-containers/workflows/tests-BST/badge.svg)
1. ![](https://github.com/shreyad8/new-containers/workflows/tests-AVLTree/badge.svg)
1. ![](https://github.com/shreyad8/new-containers/workflows/tests-Heap/badge.svg)
